@@ -1,6 +1,6 @@
 package Moment;
 {
-  $Moment::VERSION = '1.0.1';
+  $Moment::VERSION = '1.1.0';
 }
 
 # ABSTRACT: class that represents the moment in time
@@ -169,6 +169,9 @@ sub new {
         croak "Incorrect usage. new() must get one thing from the list: dt, timestamp or year/month/day/hour/minute/second. Stopped"
     }
 
+    $self->{_d} = substr($self->{_dt}, 0, 10);
+    $self->{_t} = substr($self->{_dt}, 11, 8);
+
     $self->{_weekday_name} = $self->_get_weekday_name($self->{_timestamp});
 
     return $self;
@@ -216,6 +219,28 @@ sub get_dt {
 }
 
 
+sub get_d {
+    my ($self, @params) = @_;
+
+    if (@params) {
+        croak 'Incorrect usage. get_d() shouldn\'t get any params. Stopped';
+    }
+
+    return $self->{_d};
+}
+
+
+sub get_t {
+    my ($self, @params) = @_;
+
+    if (@params) {
+        croak 'Incorrect usage. get_t() shouldn\'t get any params. Stopped';
+    }
+
+    return $self->{_t};
+}
+
+
 sub get_year {
     my ($self, @params) = @_;
 
@@ -630,7 +655,7 @@ Moment - class that represents the moment in time
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -675,6 +700,8 @@ Here are the methods to get the values that was used in constructor:
 
     #'2014-11-27 03:31:23'
     my $dt = $moment->get_dt();
+    my $d = $moment->get_d();
+    my $t = $moment->get_t();
 
     my $year = $moment->get_year();
     my $month = $moment->get_month();
@@ -815,6 +842,26 @@ The data in scalar is in format 'YYYY-MM-DD hh:mm:ss'.
 The value that return this method is in the range ['1800-01-01 00:00:00',
 '2199-12-31 23:59:59'].
 
+=head2 get_d()
+
+Returns the scalar with date of the moment stored in the object.
+The data in scalar is in format 'YYYY-MM-DD'.
+
+    say Moment->now()->get_d(); # 2014-12-07
+
+The value that return this method is in the range ['1800-01-01',
+'2199-12-31'].
+
+=head2 get_t()
+
+Returns the scalar with time of the moment stored in the object.
+The data in scalar is in format 'hh:mm:ss'.
+
+    say Moment->now()->get_t(); # 11:50:57
+
+The value that return this method is in the range ['00:00:00',
+'23:59:59'].
+
 =head2 get_year()
 
 Returns the scalar with year of the moment stored in the object.
